barrel_mcp_auth_none (barrel_mcp v2.0.2)

No authentication provider for barrel_mcp.

This is the default authentication provider that allows all requests. Use this for development, testing, or when authentication is handled at a different layer (e.g., API gateway, reverse proxy).

Summary

Functions

Always authenticate successfully. Returns an anonymous auth_info with no claims.

Return a challenge response. This should never be called since authenticate always succeeds, but we implement it for completeness.

Initialize the no-auth provider.

Functions

authenticate(Request, State)

-spec authenticate(map(), term()) -> {ok, barrel_mcp_auth:auth_info()}.

Always authenticate successfully. Returns an anonymous auth_info with no claims.

challenge(Reason, State)

-spec challenge(barrel_mcp_auth:auth_error(), term()) -> {integer(), map(), binary()}.

Return a challenge response. This should never be called since authenticate always succeeds, but we implement it for completeness.

init(Opts)

-spec init(map()) -> {ok, undefined}.

Initialize the no-auth provider.